/*
 * Oscar Shell Service
 * Copyright (c) 2004, Richard S. Hall
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of the ungoverned.org nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Contact: Richard S. Hall (heavy@ungoverned.org)
 * Contributor(s):
 *
**/
package org.ungoverned.osgi.bundle.shell;

import java.io.PrintStream;
import java.util.StringTokenizer;

import org.osgi.framework.BundleContext;
import org.ungoverned.osgi.service.shell.CdCommand;

public class CdCommandImpl implements CdCommand
{
    private BundleContext m_context = null;
    private String m_baseURL = "";

    public CdCommandImpl(BundleContext context)
    {
        m_context = context;

        // See if the initial base URL is specified.
        String baseURL = m_context.getProperty(BASE_URL_PROPERTY);
        setBaseURL(baseURL);
    }

    public String getName()
    {
        return "cd";
    }

    public String getUsage()
    {
        return "cd [<base-URL>]";
    }

    public String getShortDescription()
    {
        return "change or display base URL.";
    }

    public void execute(String s, PrintStream out, PrintStream err)
    {
        StringTokenizer st = new StringTokenizer(s, " ");

        // Ignore the command name.
        st.nextToken();

        // No more tokens means to display the base URL,
        // otherwise set the base URL.
        if (st.countTokens() == 0)
        {
            out.println(m_baseURL);
        }
        else if (st.countTokens() == 1)
        {
            setBaseURL(st.nextToken());
        }
        else
        {
            err.println("Incorrect number of arguments");
        }
    }

    public String getBaseURL()
    {
        return m_baseURL;
    }

    public void setBaseURL(String s)
    {
        m_baseURL = (s == null) ? "" : s;
    }
}