/*
 * Oscar Shell Service
 * Copyright (c) 2004, Richard S. Hall
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *   * Neither the name of the ungoverned.org nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Contact: Richard S. Hall (heavy@ungoverned.org)
 * Contributor(s):
 *
**/
package org.ungoverned.osgi.bundle.shell;

import java.io.PrintStream;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.ungoverned.osgi.service.shell.Command;
import org.ungoverned.osgi.service.shell.ShellService;

public class HelpCommandImpl implements Command
{
    private BundleContext m_context = null;

    public HelpCommandImpl(BundleContext context)
    {
        m_context = context;
    }

    public String getName()
    {
        return "help";
    }

    public String getUsage()
    {
        return "help";
    }

    public String getShortDescription()
    {
        return "display shell commands.";
    }

    public void execute(String s, PrintStream out, PrintStream err)
    {
        try {
            // Get a reference to the shell service.
            ServiceReference ref = m_context.getServiceReference(
                org.ungoverned.osgi.service.shell.ShellService.class.getName());

            if (ref != null)
            {
                ShellService ss = (ShellService) m_context.getService(ref);
                String[] cmds = ss.getCommands();
                String[] usage = new String[cmds.length];
                String[] desc = new String[cmds.length];
                int maxUsage = 0;
                for (int i = 0; i < cmds.length; i++)
                {
                    usage[i] = ss.getCommandUsage(cmds[i]);
                    desc[i] = ss.getCommandDescription(cmds[i]);
                    // Just in case the command has gone away.
                    if ((usage[i] != null) && (desc[i] != null))
                    {
                        maxUsage = Math.max(maxUsage, usage[i].length());
                    }
                }
                StringBuffer sb = new StringBuffer();
                for (int i = 0; i < cmds.length; i++)
                {
                    // Just in case the command has gone away.
                    if ((usage[i] != null) && (desc[i] != null))
                    {
                        sb.delete(0, sb.length());
                        for (int j = 0; j < (maxUsage - usage[i].length()); j++)
                        {
                            sb.append(' ');
                        }
                        out.println(usage[i] + sb + " - " + desc[i]);
                    }
                }
            }
            else
            {
                err.println("No ShellService is unavailable.");
            }
        } catch (Exception ex) {
            err.println(ex.toString());
        }
    }
}